@@ -19,13 +19,17 @@ from typing import Any, Final
 
 from ._utilities import Undefined, UndefinedType, make_hashable
 
-__all__: Final[tuple[str, ...]] = ("Error", "ErrorEnum")
+__all__: Final[tuple[str, ...]] = (
+    "Error",
+    "ErrorEnum",
+)
 
 
 class ErrorEnum(IntEnum):
     """
     An enumeration of error codes that indicates the error type that occurred.
     """
+
     #: Error occurred due the serialization or deserialization.
     PARSE_ERROR: int = -32700
     #: Error occurred due the receiving an invalid :class:`jsonrpc.Request` object.
@@ -71,6 +75,7 @@ class Error(BaseError):
     :param message: The :py:class:`str` object that contains a short description of the error.
     :param data: An any type of object that contains additional information about the error.
     """
+
     __slots__: tuple[str, ...] = ("_code", "_message", "_data")
 
     def __init__(self, *, code: int, message: str, data: Any = Undefined) -> None:
@@ -83,10 +88,7 @@ class Error(BaseError):
         return f"{self._message!s}\u0020\u0028{self._code:d}\u0029"
 
     def __repr__(self) -> str:
-        return f"<{self.__class__.__qualname__}(" \
-            f"code={self._code!r}, " \
-            f"message={self._message!r}, " \
-            f"data={self._data!r})>"
+        return f"{self.__class__.__name__}(code={self._code!r}, message={self._message!r}, data={self._data!r})"
 
     def __hash__(self) -> int:
         return hash((self._code, self._message, make_hashable(self._data)))
