@@ -22,7 +22,10 @@ from typing import Any, Final, Literal, TypeVar, overload
 from ._errors import Error
 from ._utilities import Undefined, UndefinedType, make_hashable
 
-__all__: Final[tuple[str, ...]] = ("BatchResponse", "Response")
+__all__: Final[tuple[str, ...]] = (
+    "BatchResponse",
+    "Response",
+)
 
 _BaseResponse = TypeVar("_BaseResponse", bound="BaseResponse")
 
@@ -63,7 +66,7 @@ class BaseBatchResponse(List[_BaseResponse], metaclass=ABCMeta):
         return hash(tuple(self.data))
 
     def __repr__(self) -> str:
-        return f"<{self.__class__.__qualname__}({self.data!r})>"
+        return f"{self.__class__.__name__}({self.data!r})"
 
     @property
     @abstractmethod
@@ -84,6 +87,7 @@ class Response(BaseResponse):
     :raises TypeError: If both or no one ``body`` or ``error`` attributes are set
         or response identifier isn't the same type as request identifier.
     """
+
     __slots__: tuple[str, ...] = ("_body", "_error", "_id")
 
     @overload
@@ -91,23 +95,25 @@ class Response(BaseResponse):
         self,
         *,
         body: Any,
-        response_id: str | float | UndefinedType | None = ...
-    ) -> None: ...
+        response_id: str | float | UndefinedType | None = ...,
+    ) -> None:
+        ...
 
     @overload
     def __init__(
         self,
         *,
         error: Error,
-        response_id: str | float | UndefinedType | None = ...
-    ) -> None: ...
+        response_id: str | float | UndefinedType | None = ...,
+    ) -> None:
+        ...
 
     def __init__(
         self,
         *,
         body: Any = Undefined,
         error: Error | UndefinedType = Undefined,
-        response_id: str | float | UndefinedType | None = Undefined
+        response_id: str | float | UndefinedType | None = Undefined,
     ) -> None:
         self._validate_body_and_error(body, error)
         self._body: Final[Any] = body
@@ -115,10 +121,7 @@ class Response(BaseResponse):
         self._id: Final[str | float | UndefinedType | None] = self._validate_id(response_id) and response_id
 
     def __repr__(self) -> str:
-        return f"<{self.__class__.__qualname__}(" \
-            f"body={self._body!r}, " \
-            f"error={self._error!r}, " \
-            f"response_id={self._id!r})>"
+        return f"{self.__class__.__name__}(body={self._body!r}, error={self._error!r}, response_id={self._id!r})"
 
     def __hash__(self) -> int:
         return hash((make_hashable(self._body), self._error, self._id))
@@ -130,7 +133,7 @@ class Response(BaseResponse):
 
     def _validate_body_and_error(self, body: Any, error: Error | UndefinedType) -> None:
         if isinstance(body, UndefinedType) == isinstance(error, UndefinedType):
-            raise TypeError("Either \"body\" or \"error\" attribute must be set")
+            raise TypeError("Either 'body' or 'error' attribute must be set")
 
     def _validate_id(self, response_id: Any) -> Literal[True]:
         if not isinstance(response_id, str | Number | UndefinedType | NoneType):
@@ -145,9 +148,9 @@ class Response(BaseResponse):
 
         :raises AttributeError: If the response is erroneous.
         """
-        if isinstance(self._body, UndefinedType):
-            raise AttributeError("Erroneous response hasn't \"body\" attribute")
-        return self._body
+        if isinstance(body := self._body, UndefinedType):
+            raise AttributeError("Erroneous response has not a 'body' attribute")
+        return body
 
     @property
     def error(self) -> Error:
@@ -156,9 +159,9 @@ class Response(BaseResponse):
 
         :raises AttributeError: If the response is successful.
         """
-        if isinstance(self._error, UndefinedType):
-            raise AttributeError("Successful response hasn't \"error\" attribute")
-        return self._error
+        if isinstance(error := self._error, UndefinedType):
+            raise AttributeError("Successful response has not a 'error' attribute")
+        return error
 
     @property
     def response_id(self) -> str | float | UndefinedType | None:
@@ -212,6 +215,7 @@ class BatchResponse(BaseBatchResponse[Response]):
     The :py:class:`collections.UserList` subclass representing the collection
     of :class:`jsonrpc.Response` objects.
     """
+
     __slots__: tuple[str, ...] = ()
 
     @property
