@@ -17,6 +17,7 @@ import json as _json
 import pickle as _pickle
 from abc import ABCMeta, abstractmethod
 from io import BytesIO, StringIO
+from sys import getdefaultencoding
 from typing import Any, ClassVar, Final
 
 from ._errors import Error, ErrorEnum
@@ -30,6 +31,9 @@ __all__: Final[tuple[str, ...]] = (
 class BaseSerializer(metaclass=ABCMeta):
     __slots__: tuple[str, ...] = ()
 
+    #: Returns the name of the current default string encoding:
+    DEFAULT_ENCODING: ClassVar[str] = getdefaultencoding()
+
     def __repr__(self) -> str:
         return f"{self.__class__.__name__}()"
 
@@ -59,8 +63,8 @@ class JSONSerializer(BaseSerializer):
         """
         with StringIO() as raw_buffer:
             try:
-                _json.dump(obj, raw_buffer, separators=(",", ":"))
-                return raw_buffer.getvalue().encode("latin-1")
+                _json.dump(obj, raw_buffer, ensure_ascii=False, separators=(",", ":"))
+                return raw_buffer.getvalue().encode(self.DEFAULT_ENCODING)
             except Exception as exc:
                 raise Error(code=ErrorEnum.PARSE_ERROR, message="Failed to serialize object to JSON") from exc
 
