@@ -14,15 +14,25 @@
 # limitations under the License.
 
 from collections.abc import Iterable, MutableMapping
-from typing import Any, Final, Literal
+from typing import Any, Final, Literal, TypeGuard
 
 __all__: Final[tuple[str, ...]] = (
+    "is_iterable",
     "make_hashable",
     "Undefined",
-    "UndefinedType"
+    "UndefinedType",
 )
 
 
+def is_iterable(obj: Any) -> TypeGuard[Iterable[Any]]:
+    try:
+        iter(obj)
+    except TypeError:
+        return False
+    else:
+        return True
+
+
 def make_hashable(obj: Any) -> Any:
     if isinstance(obj, MutableMapping):
         return tuple((key, make_hashable(value)) for key, value in sorted(obj.items()))
@@ -32,7 +42,7 @@ def make_hashable(obj: Any) -> Any:
     try:
         hash(obj)
     except TypeError:
-        if isinstance(obj, Iterable):
+        if is_iterable(obj):
             return tuple(map(make_hashable, obj))
         # Non-hashable, non-iterable:
         raise
